bearermanagement/mpm/inc/mpmserver.h
branchRCL_3
changeset 45 4c83dcfb6f1a
parent 26 0a9e01492035
child 55 fc7b30ed2058
--- a/bearermanagement/mpm/inc/mpmserver.h	Wed Jun 09 10:07:12 2010 +0300
+++ b/bearermanagement/mpm/inc/mpmserver.h	Mon Jun 21 16:06:29 2010 +0300
@@ -352,18 +352,21 @@
                                  TConnectionState&   aState );
 
         /**
         * Checks if the connection is started for the Iap Id.
         * @since 3.2
         * @param aIapId IAP Id of the connection
         * @param aConnId Connection Id
+        * @return Connection State, EIdle if not found
         */
-        TBool CheckIfStarted( const TUint32 aIapId, 
+        TConnectionState CheckUsageOfIap( const TUint32 aIapId, 
                               const TConnectionId aConnId );
 
         /**
-        * Checks if a connection is started with wlan iap.
+        * Checks if any WLAN connection is started.
         * @since 3.2
         * @param aCdbAccess
+		* @return IAP ID of the started WLAN connection, zero if not found
         */
         TUint32 IsWlanConnectionStartedL( const CMPMCommsDatAccess* aCdbAccess );
         
@@ -421,6 +424,7 @@
         * preferred IAP notifications.
         * @since 3.2
         * @param aConnId Connection Id
+        * @return ETrue if registered
         */
         TBool RegisteredForBMPrefIAP( const TConnectionId aConnId );
 
@@ -623,8 +627,9 @@
         void AppendWlanQueryQueueL( CMPMWlanQueryDialog* aDlg );
 
         /**
-        * Removes the first item from the iWlanQueryQueue.
+        * Removes the dialog from the iWlanQueryQueue.
         * @since 3.2
+        * @param aDlg dialog to be removed.
         */
         inline void RemoveFromWlanQueryQueue( CMPMWlanQueryDialog* aDlg );
 
@@ -704,6 +709,7 @@
         * Returns the Commsdat access instance
         *
         * @since 3.2
+        * @return Commsdat access instance.
         */
         inline CMPMCommsDatAccess* CommsDatAccess();
 
@@ -719,6 +725,7 @@
         * Starts forced roaming sequence to connected wlan
         *
         * @param aIapInfo Info about available IAPs
+        * @return Always zero...
         * @since 5.2
         */
         static TInt StartForcedRoamingToConnectedWlanL( TAny* aUpdater );
@@ -735,6 +742,7 @@
         * Checks whether phone is in visitor network.
         *
         * @since 5.2
+		* @return ETrue if phone is in visitor network, EFalse otherwise
         */
         TBool IsVisitorNetwork() const;
         
@@ -742,6 +750,7 @@
         * Returns the RoamingWatcher pointer
         *
         * @since 5.2
+		* @return RoamingWatcher pointer
         */
         inline CMPMRoamingWatcher* RoamingWatcher() const;
         
@@ -759,7 +768,11 @@
         CSession2* NewSessionL( const TVersion& aVersion,
                                 const RMessage2& aMessage) const;
 
-        // Stops connection of certain IAP, zero for all connections
+        /**
+		* Stops either all connections or a certain IAP
+		*
+        * @param IAP ID to be stopped, zero for all connections
+		*/
         void StopConnections( TInt aIapId = 0 );
 
     public:
@@ -867,24 +880,28 @@
         /**
         * Offline mode watcher updates the mode variable stored by MPM server.
         * @since 5.2
+        * @param aNewModeValue New offline mode value
         */
-        void UpdateOfflineMode( TInt newModeValue );
+        void UpdateOfflineMode( TInt aNewModeValue );
 
         /**
         * Returns true if the phone is in offline mode.
         * @since 5.2
+        * @return ETrue if phone is in offline mode, EFalse otherwise.
         */
         TBool IsPhoneOffline();
 
         /**
         * Tells the "Use WLAN in offline mode" query response.
         * @since 5.2
+        * @return Response of offline mode query (Undefined if not executed)
         */
         TOfflineWlanQueryResponse OfflineWlanQueryResponse();
 
         /**
         * Called when the "Use WLAN in offline mode" query has been responded.
         * @since 5.2
+        * @param aResponse Sets the Offline mode query response value.
         */
         void SetOfflineWlanQueryResponse( TOfflineWlanQueryResponse aResponse);
@@ -352,18 +352,21 @@
 
         /**
-        * Checks if the connection is started for the Iap Id.
+        * Checks if the connection is started for the Iap Id,
+        * returning the state.
         * @since 3.2
         * @param aIapId IAP Id of the connection